summaryrefslogtreecommitdiffstats
path: root/native/src/svg.rs
diff options
context:
space:
mode:
authorLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2022-12-06 04:34:00 +0100
committerLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2022-12-06 04:34:00 +0100
commitb205a663471a8170d7b30cc59894425c09bea563 (patch)
tree53514f16226949f1e2440eed8ead4dec968c8d95 /native/src/svg.rs
parent314b0f7dc52c844669c224060a7b03e842762370 (diff)
downloadiced-b205a663471a8170d7b30cc59894425c09bea563.tar.gz
iced-b205a663471a8170d7b30cc59894425c09bea563.tar.bz2
iced-b205a663471a8170d7b30cc59894425c09bea563.zip
Remove `appearance` from `Handle`
... and pass it directly to `Renderer::draw` instead.
Diffstat (limited to 'native/src/svg.rs')
-rw-r--r--native/src/svg.rs20
1 files changed, 3 insertions, 17 deletions
diff --git a/native/src/svg.rs b/native/src/svg.rs
index 08b0984a..2168e409 100644
--- a/native/src/svg.rs
+++ b/native/src/svg.rs
@@ -1,19 +1,16 @@
//! Load and draw vector graphics.
-use crate::{Hasher, Rectangle, Size};
+use crate::{Color, Hasher, Rectangle, Size};
use std::borrow::Cow;
use std::hash::{Hash, Hasher as _};
use std::path::PathBuf;
use std::sync::Arc;
-pub use iced_style::svg::{Appearance, StyleSheet};
-
/// A handle of Svg data.
#[derive(Debug, Clone)]
pub struct Handle {
id: u64,
data: Arc<Data>,
- appearance: Appearance,
}
impl Handle {
@@ -39,7 +36,6 @@ impl Handle {
Handle {
id: hasher.finish(),
data: Arc::new(data),
- appearance: Appearance::default(),
}
}
@@ -52,16 +48,6 @@ impl Handle {
pub fn data(&self) -> &Data {
&self.data
}
-
- /// Returns the styling [`Appearance`] for the SVG.
- pub fn appearance(&self) -> Appearance {
- self.appearance
- }
-
- /// Set the [`Appearance`] for the SVG.
- pub fn set_appearance(&mut self, appearance: Appearance) {
- self.appearance = appearance;
- }
}
impl Hash for Handle {
@@ -98,6 +84,6 @@ pub trait Renderer: crate::Renderer {
/// Returns the default dimensions of an SVG for the given [`Handle`].
fn dimensions(&self, handle: &Handle) -> Size<u32>;
- /// Draws an SVG with the given [`Handle`] and inside the provided `bounds`.
- fn draw(&mut self, handle: Handle, bounds: Rectangle);
+ /// Draws an SVG with the given [`Handle`], an optional [`Color`] filter, and inside the provided `bounds`.
+ fn draw(&mut self, handle: Handle, color: Option<Color>, bounds: Rectangle);
}